@@ -538,7 +538,7 @@ impl ProcessMemory {
         #[cfg(target_family = "windows")]
         close_valid_handle(self.handle as _);
         #[cfg(target_os = "macos")]
-        mach::mach_port::mach_port_deallocate(mach::traps::mach_task_self(), self.handle as _);
+        unsafe { mach::mach_port::mach_port_deallocate(mach::traps::mach_task_self(), self.handle as _) };
         #[cfg(target_vendor = "unknown")]
         ptrace::detach(nix_pid, None).unwrap(); 
     }
